@@ -47,9 +47,12 @@ int main(int argc, char **argv)
     QQmlDebuggingEnabler debugEnabler;
 
     QApplication app(argc, argv);
-    KDBusService service(KDBusService::Multiple);
+    KLocalizedString::setApplicationDomain("plasmoidviewer");
 
+    app.setApplicationName(QStringLiteral("plasmoidviewer"));
+    app.setOrganizationDomain(QStringLiteral("kde.org"));
     app.setApplicationVersion(version);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("plasma"), app.windowIcon()));
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Run Plasma widgets in their own window"));
@@ -88,6 +91,8 @@ int main(int argc, char **argv)
     parser.addVersionOption();
     parser.process(app);
 
+    KDBusService service(KDBusService::Multiple);
+
     const QString applet = parser.value("applet");
     if (applet.isEmpty()) {
         qWarning() << "An applet name must be specified";
